@@ -220,7 +220,7 @@ void crashrecover()
    }
    xobjs.tempfile = strdup(_STR2);
 
-   startloadfile();
+   startloadfile(-1);
 }
 
 /*----------------------------------------------------------------------*/
@@ -394,7 +394,7 @@ void listfiles(xcWidget w, popupstruct *okaystruct, caddr_t calldata)
 	    else if (match_filter(dp->d_name, filter))
 	       files[flfiles].filetype = MATCH;
 	    else {
-	       if (areawin->filefilter)
+	       if (xobjs.filefilter)
 		  continue;
 	       else
 	          files[flfiles].filetype = NONMATCH;
@@ -479,7 +479,7 @@ void newfilelist(xcWidget w, popupstruct *okaystruct)
       Wprintf("Error: Bad variable $XCOps(filter) in Tcl!");
       return;  
    }
-   areawin->filefilter = bval;
+   xobjs.filefilter = bval;
 #endif
 
    for (n = 0; n < flfiles; n++)
@@ -704,7 +704,7 @@ void draglscroll(xcWidget w, popupstruct *okaystruct, XButtonEvent *event)
 
 void setfilefilter(xcWidget w, popupstruct *okaystruct, caddr_t calldata)
 {
-   areawin->filefilter = (areawin->filefilter) ? False : True;
+   xobjs.filefilter = (xobjs.filefilter) ? False : True;
 
    /* Force regeneration of the file list */
 
@@ -794,7 +794,7 @@ void genfilelist(xcWidget parent, popupstruct *okaystruct, Dimension width)
    wwidth = XTextWidth(appdata.xcfont, "filter", strlen("filter"));
    XtnSetArg(XtNx, width - wwidth - 50);
    XtnSetArg(XtNy, LISTHEIGHT + 10);
-   XtnSetArg(XtNset, areawin->filefilter);
+   XtnSetArg(XtNset, xobjs.filefilter);
    XtnSetArg(XtNsquare, True);
    XtnSetArg(XtNborderWidth, 0);
    XtnSetArg(XtNfont, appdata.xcfont);
