@@ -303,7 +303,7 @@ void starthelp(xcWidget button, caddr_t clientdata, caddr_t calldata)
    xcWidget	popup, cancelbutton, hspace, help2, hsb;
    short 	n = 0;
    popupstruct  *okaystruct;
-   buttonsave   *savebutton = (buttonsave *)malloc(sizeof(buttonsave));
+   buttonsave   *savebutton;
    Dimension    areawidth, bwidth, pheight;
    Position	xpos, ypos;
    u_int	xmax, ymax;
@@ -329,7 +329,7 @@ void starthelp(xcWidget button, caddr_t clientdata, caddr_t calldata)
    /*  Always direct the call to the main menu button. */
    button = OptionsHelpButton;
 
-   getgeneric(savebutton, button, starthelp, NULL);
+   savebutton = getgeneric(button, starthelp, NULL);
 
    /* Generate the pixmap and write the help text to it */
 
