@@ -783,7 +783,8 @@ void composelib(short mode)
    short llx, lly, width, height;
 
    int totalarea, targetwidth;
-   double scale;
+   double scale, savescale;
+   XPoint savepos;
 
    /* Also make composelib() a wrapper for composepagelib() */
    if ((mode > FONTLIB) && (mode < LIBRARY)) {
@@ -798,6 +799,11 @@ void composelib(short mode)
    for (pgen = libpage->plist; pgen < libpage->plist + libpage->parts; pgen++)
       if (IS_OBJINST(*pgen)) *pgen = NULL;
 
+   /* Before resetting, save the position and scale.  We will restore	*/
+   /* them at the end.							*/
+
+   savepos = libpage->pcorner;
+   savescale = libpage->viewscale;
    reset(libpage, NORMAL);
 
    /* Return if library defines no objects or virtual instances */
@@ -912,6 +918,10 @@ void composelib(short mode)
 
    /* Update the library directory */
    updatepagelib(LIBLIB, mode);
+
+   /* Restore original view position */
+   libpage->pcorner = savepos;
+   libpage->viewscale = savescale;
 }
 
 /*----------------------------------------------------------------*/
@@ -985,6 +995,7 @@ void catvirtualcopy()
 
    clearselects();
    composelib(LIBRARY + i);
+   lib_mark_changed(i);
    drawarea(NULL, NULL, NULL);
 }
 
@@ -1116,7 +1127,10 @@ void catdelete()
 
    clearselects();
 
-   if ((i = is_library(topobject)) >= 0) composelib(LIBRARY + i);
+   if ((i = is_library(topobject)) >= 0) {
+      composelib(LIBRARY + i);
+      lib_mark_changed(i);
+   }
 
    drawarea(NULL, NULL, NULL);
 }
@@ -1196,6 +1210,37 @@ void linkedlistinsertafter(liblistptr *spec, int o1, int o2)
    }
 }
 
+/*------------------------------------------------------*/
+/* Set the "changed" flag in a library if any object	*/
+/* in that library has changed.				*/
+/*------------------------------------------------------*/
+
+void lib_set_changes(libnum)
+{
+   int j;
+   objectptr thisobj;
+
+   if ((xobjs.userlibs[libnum].flags & LIBRARY_CHANGED) != 0)
+      return;
+
+   for (j = 0; j < xobjs.userlibs[libnum].number; j++) {
+      thisobj = *(xobjs.userlibs[libnum].library + j);
+      if (getchanges(thisobj) > 0) {
+	 xobjs.userlibs[libnum].flags |= LIBRARY_CHANGED;
+	 break;
+      }
+   }
+}
+
+/*------------------------------------------------------*/
+/* Mark a library as having been modified.		*/
+/*------------------------------------------------------*/
+
+void lib_mark_changed(int libnum)
+{
+   xobjs.userlibs[libnum].flags |= LIBRARY_CHANGED;
+}
+
 /*------------------------------------------------------*/
 /* Rearrange objects in the library			*/
 /*------------------------------------------------------*/
@@ -1291,11 +1336,11 @@ void catmove(int x, int y)
 
    unselect_all();
    composelib(LIBRARY + i);
-   incr_changes(xobjs.libtop[LIBRARY + i]->thisobject);
+   lib_mark_changed(i);
    if (j != i) {
       composelib(LIBRARY + j);
       centerview(xobjs.libtop[LIBRARY + j]);
-      incr_changes(xobjs.libtop[LIBRARY + j]->thisobject);
+      lib_mark_changed(j);
    }
 
    drawarea(NULL, NULL, NULL);
@@ -1474,6 +1519,7 @@ void copycat()
    addtoinstlist(USERLIB - LIBRARY, *newobj, FALSE);
 
    composelib(USERLIB);
+   lib_mark_changed(USERLIB - LIBRARY);
    unselect_all();
 
    if (areawin->topinstance == xobjs.libtop[USERLIB])
