@@ -18,6 +18,7 @@
 #define setaction(b,c)  NULL, 1, NULL, NULL
 #define toolaction(b,c) NULL, NULL
 #define noaction        NULL, 0, NULL, NULL
+#define offset(a)	0
 
 #else                   /* real definitions. . .*/
 
@@ -27,6 +28,7 @@
 #define setaction(b,c)	NULL, 1, (XtCallbackProc)b, c
 #define toolaction(b,c) (XtCallbackProc)b, c
 #define noaction	NULL, 0, (XtCallbackProc)DoNothing, NULL
+#define offset(a)	Number(XtOffset(XCWindowDataPtr, a))
 
 #endif
 
@@ -176,7 +178,7 @@ menustruct Stipples[] = {
 };
 
 menustruct TextMenu[] = {
-	{"Text Size", action(gettsize, &areastruct.textscale)},
+	{"Text Size", action(gettsize, NULL)},
 	{"Font", submenu(Fonts)},
 	{"Style", submenu(FontStyles)},
 	{"Encoding", submenu(FontEncodings)},
@@ -197,8 +199,8 @@ menustruct PolyMenu[] = {
 	{" ", noaction},
 	{"Object size", action(getosize, NULL)},
 	{"Parameters", submenu(Parameterize)},
-	{"Center Object", setaction(toggle, &areastruct.center)},
-	{"Manhattan Draw", action(toggle, &areastruct.manhatn)},
+	{"Center Object", setaction(toggle, offset(center))},
+	{"Manhattan Draw", action(toggle, offset(manhatn))},
 	{"Polygon Edit", submenu(BoxEditStyles)},
 };
 
@@ -236,14 +238,14 @@ menustruct LineMenu[] = {
 };
 
 menustruct GridMenu[] = {
-	{"Grid", setaction(toggle, &areastruct.gridon)},
-	{"Axes", setaction(toggle, &areastruct.axeson)},
+	{"Grid", setaction(toggle, offset(gridon))},
+	{"Axes", setaction(toggle, offset(axeson))},
 	{"Grid spacing", action(getgridspace, NULL)},
 	{"Grid type/display", submenu(GridStyles)},
 };
 
 menustruct SnapMenu[] = {
-	{"Snap-to", setaction(toggle, &areastruct.snapto)},
+	{"Snap-to", setaction(toggle, offset(snapto))},
         {"Snap spacing", action(getsnapspace, NULL)},
 };
 
@@ -296,13 +298,6 @@ menustruct FileMenu[] = {
 	{"Execute script", action(getfile, Number(SCRIPT))},
 	{"Write Xcircuit PS (W)", action(outputpopup, NULL)},
 	{" ", noaction},
-#ifdef USE_WIN32_COM
-	{"Execute Windows script (JScript/VBScript)", action(getfile, Number(COMSCRIPT))},
-#ifdef USE_WIN32_DOTNET
-	{"Load .NET plugin", action(getfile, Number(COMDOTNET))},
-#endif
-	{" ", noaction},
-#endif
 	{"Add To Library", action(getlib, NULL)},
 	{"Load New Library", action(getuserlib, NULL)},
 	{"Save Library", action(savelibpopup, Number(0))},
@@ -313,11 +308,10 @@ menustruct FileMenu[] = {
 };
 
 menustruct OptionMenu[] = {
-	{"Alt Colors", action(inversecolor, &areastruct.invert)},
-	{"Show Bounding box", action(toggle, &areastruct.bboxon)},
-	{"Edit in place", setaction(toggle, &areastruct.editinplace)},
-	{"Show Pin Positions", action(toggle, &areastruct.pinpointon)},
-	{"Enable XSchema", action(doxschema, Number(1))},
+	{"Alt Colors", action(inversecolor, offset(invert))},
+	{"Show Bounding box", action(toggle, offset(bboxon))},
+	{"Edit in place", setaction(toggle, offset(editinplace))},
+	{"Show Pin Positions", action(toggle, offset(pinpointon))},
 #ifdef HAVE_XPM
 	{"Disable Toolbar", action(dotoolbar, NULL)},
 #endif
@@ -431,5 +425,6 @@ short toolbuttons = sizeof(ToolBar) / sizeof(toolbarstruct);
 #undef setaction
 #undef toolaction
 #undef noaction
+#undef offset
 
 /*-------------------------------------------------------------------------*/
