@@ -12,18 +12,14 @@
 #include <stdlib.h>
 #include <string.h>
 
-#ifndef XC_WIN32
 #include <X11/Intrinsic.h>
 #include <X11/StringDefs.h>
-#endif
 
 #ifdef TCL_WRAPPER 
 #include <tk.h>
 #else
-#ifndef XC_WIN32
 #include "Xw/Xw.h"
 #endif
-#endif
 
 /*----------------------------------------------------------------------*/
 /* Local includes							*/
@@ -45,10 +41,8 @@
 extern Tcl_Interp *xcinterp;
 #endif
 extern Globaldata xobjs;
-extern Clientdata areastruct;
-#ifndef TCL_WRAPPER
+extern XCWindowData *areawin;
 extern Widget     menuwidgets[];
-#endif
 extern short textpos, textend;
 extern char _STR[150];
 
@@ -77,14 +71,10 @@ u_char param_select[] = {
 };
 
 #ifdef TCL_WRAPPER
-#ifndef _MSC_VER
 xcWidget *param_buttons[] = {
    /* To be done---map buttons to Tk_Windows! */
 };
 #else
-xcWidget *param_buttons[];
-#endif
-#else
 Widget *param_buttons[] = {
    &ParametersNumericButton,		/* P_NUMERIC */
    &ParametersSubstringButton,		/* P_SUBSTRING */
@@ -725,13 +715,30 @@ int psubstitute(objinstptr thisinst)
 {
    objinstptr pinst;
    objectptr thisobj;
+   genericptr *eptr;
+   stringpart *strptr;
 
-   pinst = (thisinst == areastruct.topinstance) ? areastruct.topinstance : thisinst;
+   pinst = (thisinst == areawin->topinstance) ? areawin->topinstance : thisinst;
    if (pinst == NULL) return -1;		/* there is no instance */
-   else if (pinst->thisobject->params == NULL)
+   thisobj = pinst->thisobject;
+
+   /* Perform expression parameter substitutions on all labels.	*/
+   /* Note that this used to be done on an immediate basis as	*/
+   /* labels were parsed.  The main difference is that only one	*/
+   /* expression parameter can be used per label if it is to	*/
+   /* compute the result of some aspect of the label, such as	*/
+   /* position; this is a tradeoff for much simplified handling	*/
+   /* of expression results, like having to avoid infinite	*/
+   /* recursion in an expression result.			*/
+
+   for (eptr = thisobj->plist; eptr < thisobj->plist + thisobj->parts; eptr++)
+      if ((*eptr)->type == LABEL)
+	 for (strptr = (TOLABEL(eptr))->string; strptr != NULL; strptr =
+			nextstringpartrecompute(strptr, pinst));
+
+   if (thisobj->params == NULL)
       return -1;			    /* object has no parameters */
 
-   thisobj = (pinst == NULL) ? topobject : pinst->thisobject;
    return opsubstitute(thisobj, pinst);
 }
 
@@ -807,127 +814,127 @@ void pwriteback(objinstptr thisinst)
 	          case P_POSITION_X:
 	             switch(thiselem->type) {
 	                case OBJINST:
-		           wtemp.ival = TOOBJINST(&thiselem)->position.x;
+		           wtemp.ival = TOOBJINST(eptr)->position.x;
 		           break;
 	                case LABEL:
-		           wtemp.ival = TOLABEL(&thiselem)->position.x;
+		           wtemp.ival = TOLABEL(eptr)->position.x;
 		           break;
 	                case POLYGON:
-	                   setpt = TOPOLY(&thiselem)->points + k;
+	                   setpt = TOPOLY(eptr)->points + k;
 		           wtemp.ival = setpt->x;
 		           break;
 	                case ARC:
-		           wtemp.ival = TOARC(&thiselem)->position.x;
+		           wtemp.ival = TOARC(eptr)->position.x;
 		           break;
 	                case SPLINE:
-		           wtemp.ival = TOSPLINE(&thiselem)->ctrl[k].x;
+		           wtemp.ival = TOSPLINE(eptr)->ctrl[k].x;
 		           break;
 	             }
 	             break;
 	          case P_POSITION_Y:
 	             switch(thiselem->type) {
 	                case OBJINST:
-		           wtemp.ival = TOOBJINST(&thiselem)->position.y;
+		           wtemp.ival = TOOBJINST(eptr)->position.y;
 		           break;
 	                case LABEL:
-		           wtemp.ival = TOLABEL(&thiselem)->position.y;
+		           wtemp.ival = TOLABEL(eptr)->position.y;
 		           break;
 	                case POLYGON:
-	                   setpt = TOPOLY(&thiselem)->points + k;
+	                   setpt = TOPOLY(eptr)->points + k;
 		           wtemp.ival = setpt->y;
 		           break;
 	                case ARC:
-		           wtemp.ival = TOARC(&thiselem)->position.y;
+		           wtemp.ival = TOARC(eptr)->position.y;
 		           break;
 	                case SPLINE:
-		           wtemp.ival = TOSPLINE(&thiselem)->ctrl[k].y;
+		           wtemp.ival = TOSPLINE(eptr)->ctrl[k].y;
 		           break;
 	             }
 	             break;
 	          case P_STYLE:
 	             switch(thiselem->type) {
 	                case POLYGON:
-		           wtemp.ival = TOPOLY(&thiselem)->style;
+		           wtemp.ival = TOPOLY(eptr)->style;
 		           break;
 	                case ARC:
-		           wtemp.ival = TOARC(&thiselem)->style;
+		           wtemp.ival = TOARC(eptr)->style;
 		           break;
 	                case SPLINE:
-		           wtemp.ival = TOSPLINE(&thiselem)->style;
+		           wtemp.ival = TOSPLINE(eptr)->style;
 		           break;
 	                case PATH:
-		           wtemp.ival = TOPATH(&thiselem)->style;
+		           wtemp.ival = TOPATH(eptr)->style;
 		           break;
 	             }
 	             break;
 	          case P_JUSTIFY:
 	             switch(thiselem->type) {
 	                case LABEL:
-		           wtemp.ival = TOLABEL(&thiselem)->justify;
+		           wtemp.ival = TOLABEL(eptr)->justify;
 		           break;
 	             }
 	             break;
 	          case P_ANGLE1:
 	             switch(thiselem->type) {
 	                case ARC:
-		           wtemp.fval = TOARC(&thiselem)->angle1;
+		           wtemp.fval = TOARC(eptr)->angle1;
 		           break;
 	             }
 	             break;
 	          case P_ANGLE2:
 	             switch(thiselem->type) {
 	                case ARC:
-		           wtemp.fval = TOARC(&thiselem)->angle1;
+		           wtemp.fval = TOARC(eptr)->angle1;
 		           break;
 	             }
 	             break;
 	          case P_RADIUS:
 	             switch(thiselem->type) {
 	                case ARC:
-		           wtemp.ival = TOARC(&thiselem)->radius;
+		           wtemp.ival = TOARC(eptr)->radius;
 		           break;
 	             }
 	             break;
 	          case P_MINOR_AXIS:
 	             switch(thiselem->type) {
 	                case ARC:
-		           wtemp.ival = TOARC(&thiselem)->yaxis;
+		           wtemp.ival = TOARC(eptr)->yaxis;
 		           break;
 	             }
 	             break;
 	          case P_ROTATION:
 	             switch(thiselem->type) {
 	                case OBJINST:
-		           wtemp.ival = TOOBJINST(&thiselem)->rotation;
+		           wtemp.ival = TOOBJINST(eptr)->rotation;
 		           break;
 	                case LABEL:
-		           wtemp.ival = TOLABEL(&thiselem)->rotation;
+		           wtemp.ival = TOLABEL(eptr)->rotation;
 		           break;
 	             }
 	             break;
 	          case P_SCALE:
 	             switch(thiselem->type) {
 	                case OBJINST:
-		           wtemp.fval = TOOBJINST(&thiselem)->scale;
+		           wtemp.fval = TOOBJINST(eptr)->scale;
 		           break;
 	                case LABEL:
-		           wtemp.fval = TOLABEL(&thiselem)->scale;
+		           wtemp.fval = TOLABEL(eptr)->scale;
 		           break;
 	             }
 	             break;
 	          case P_LINEWIDTH:
 	             switch(thiselem->type) {
 	                case POLYGON:
-		           wtemp.fval = TOPOLY(&thiselem)->width;
+		           wtemp.fval = TOPOLY(eptr)->width;
 		           break;
 	                case ARC:
-		           wtemp.fval = TOARC(&thiselem)->width;
+		           wtemp.fval = TOARC(eptr)->width;
 		           break;
 	                case SPLINE:
-		           wtemp.fval = TOSPLINE(&thiselem)->width;
+		           wtemp.fval = TOSPLINE(eptr)->width;
 		           break;
 	                case PATH:
-		           wtemp.fval = TOPATH(&thiselem)->width;
+		           wtemp.fval = TOPATH(eptr)->width;
 		           break;
 	             }
 	             break;
@@ -953,11 +960,16 @@ void pwriteback(objinstptr thisinst)
 
    if (pinst != NULL) resolveparams(pinst);
 
+   if (need_redraw) {
+      incr_changes(thisobj);
+      invalidate_netlist(thisobj);
+   }
+
    /* Because more than one element may use the same parameter,		*/
    /* pwriteback checks for cases in which a change in one element	*/
    /* precipitates a change in another.  If so, force a redraw.		*/
 
-   if (need_redraw && (thisinst == areastruct.topinstance))
+   if (need_redraw && (thisinst == areawin->topinstance))
       drawarea(NULL, NULL, NULL);
 }
 
@@ -1304,12 +1316,6 @@ void makenumericalp(genericptr *gelem, u_int mode, char *key)
       return;
    }
 
-   /* Cannot form this type of parameter on a top-level page */
-   if (is_page(topobject) != -1) {
-      Wprintf("Cannot form a parameter in a top-level page!");
-      return;
-   }
-
    /* Make sure the parameter doesn't already exist.	   */
 
    for (epp = (*gelem)->passed; epp != NULL; epp = epp->next) {
@@ -1361,10 +1367,10 @@ void makenumericalp(genericptr *gelem, u_int mode, char *key)
 			"a parameter of a different type\n");
 	 goto param_done;
       }
-      if ((newops = match_instance_param(areastruct.topinstance, keyptr)) == NULL) {
+      if ((newops = match_instance_param(areawin->topinstance, keyptr)) == NULL) {
          newops = make_new_parameter(keyptr);
-         newops->next = areastruct.topinstance->params;
-         areastruct.topinstance->params = newops;
+         newops->next = areawin->topinstance->params;
+         areawin->topinstance->params = newops;
          newops->type = ops->type;
          newops->which = ops->which;
       }
@@ -1455,14 +1461,14 @@ void makenumericalp(genericptr *gelem, u_int mode, char *key)
          case POLYGON:
 	    switch(mode) {
 	       case P_POSITION_X:
-	          pptr = TOPOLY(gelem)->points + areastruct.editcycle; 
+	          pptr = TOPOLY(gelem)->points + areawin->editcycle; 
 	          newops->parameter.ivalue = (int)pptr->x;
-	          epp->pdata.pointno = areastruct.editcycle;
+	          epp->pdata.pointno = areawin->editcycle;
 	          break;
 	       case P_POSITION_Y:
-	          pptr = TOPOLY(gelem)->points + areastruct.editcycle; 
+	          pptr = TOPOLY(gelem)->points + areawin->editcycle; 
 	          newops->parameter.ivalue = (int)pptr->y;
-	          epp->pdata.pointno = areastruct.editcycle;
+	          epp->pdata.pointno = areawin->editcycle;
 	          break;
 	       case P_STYLE:
 	          newops->parameter.ivalue = (int)TOPOLY(gelem)->style;
@@ -1476,14 +1482,14 @@ void makenumericalp(genericptr *gelem, u_int mode, char *key)
          case SPLINE:
 	    switch(mode) {
 	       case P_POSITION_X:
-	          pptr = TOSPLINE(gelem)->ctrl + areastruct.editcycle; 
+	          pptr = TOSPLINE(gelem)->ctrl + areawin->editcycle; 
 	          newops->parameter.ivalue = (int)pptr->x;
-	          epp->pdata.pointno = areastruct.editcycle;
+	          epp->pdata.pointno = areawin->editcycle;
 	          break;
 	       case P_POSITION_Y:
-	          pptr = TOSPLINE(gelem)->ctrl + areastruct.editcycle; 
+	          pptr = TOSPLINE(gelem)->ctrl + areawin->editcycle; 
 	          newops->parameter.ivalue = (int)pptr->y;
-	          epp->pdata.pointno = areastruct.editcycle;
+	          epp->pdata.pointno = areawin->editcycle;
 	          break;
 	       case P_STYLE:
 	          newops->parameter.ivalue = (int)TOSPLINE(gelem)->style;
@@ -1638,7 +1644,7 @@ void insertparam()
             sptr += strlen(sptr);
 	 }
       }
-      Wprintf(sstart);
+      Wprintf("%s", sstart);
       free(sstart);
 
       /* Need a new non-Tcl version method . . . */
@@ -1663,13 +1669,6 @@ void makeparam(labelptr thislabel, char *key)
    stringpart *begpart, *endpart;
    char *newkey;
 
-   /* cannot form a parameter on a top-level page */
-
-   if (is_page(topobject) != -1) {
-      Wprintf("Cannot form a parameter in a top-level page!");
-      return;
-   }
-
    /* make sure this does not overlap another parameter */
 
    if (paramcross(topobject, thislabel)) {
@@ -1686,16 +1685,16 @@ void makeparam(labelptr thislabel, char *key)
    /* intended parameter boundaries				*/
 
    if (textend > 0 && textend < textpos) {  	/* partial string */
-      splitstring(textend, &thislabel->string, areastruct.topinstance);
-      splitstring(textpos, &thislabel->string, areastruct.topinstance);
+      splitstring(textend, &thislabel->string, areawin->topinstance);
+      splitstring(textpos, &thislabel->string, areawin->topinstance);
 
       /* Because "splitstring" changes all the pointers, find the    */
       /* stringpart structures at textend and textpos positions.     */
 
       begpart = findstringpart(textend, NULL, thislabel->string,
-		areastruct.topinstance);
+		areawin->topinstance);
       endpart = findstringpart(textpos, NULL, thislabel->string,
-		areastruct.topinstance);
+		areawin->topinstance);
 
       /* Make the new segments for PARAM_START and PARAM_END.	*/
 
@@ -1945,11 +1944,11 @@ void unparameterize(int mode)
    else
       ptype = ALL_TYPES;
 
-   if ((areastruct.selects == 1) && (mode == P_SUBSTRING) && textend > 0
+   if ((areawin->selects == 1) && (mode == P_SUBSTRING) && textend > 0
 		&& textend < textpos) {
-      if (SELECTTYPE(areastruct.selectlist) != LABEL) return;	 /* Not a label */
-      settext = SELTOLABEL(areastruct.selectlist);
-      strptr = findstringpart(textend, &locpos, settext->string, areastruct.topinstance);
+      if (SELECTTYPE(areawin->selectlist) != LABEL) return;	 /* Not a label */
+      settext = SELTOLABEL(areawin->selectlist);
+      strptr = findstringpart(textend, &locpos, settext->string, areawin->topinstance);
       while (strptr != NULL && strptr->type != PARAM_END)
 	 strptr = strptr->nextpart;
       if (strptr == NULL) return;	/* No parameters */
@@ -1960,16 +1959,16 @@ void unparameterize(int mode)
       /* the whole parameter or the parameter start marker.		  */
 
       for (tmpptr = settext->string; tmpptr != NULL && tmpptr != strptr;
-		tmpptr = nextstringpart(tmpptr, areastruct.topinstance))
+		tmpptr = nextstringpart(tmpptr, areawin->topinstance))
 	 if (tmpptr->type == PARAM_START) lastptr = tmpptr;
       /* Finish search, unlinking any parameter we might be inside */
-      for (; tmpptr != NULL; tmpptr = nextstringpart(tmpptr, areastruct.topinstance));
+      for (; tmpptr != NULL; tmpptr = nextstringpart(tmpptr, areawin->topinstance));
 
       if (lastptr != NULL) unmakeparam(settext, lastptr);
    }
    else {
-      for (fselect = areastruct.selectlist; fselect < areastruct.selectlist +
-            areastruct.selects; fselect++) {
+      for (fselect = areawin->selectlist; fselect < areawin->selectlist +
+            areawin->selects; fselect++) {
          if ((mode == P_SUBSTRING) && SELECTTYPE(fselect) == LABEL) {
             settext = SELTOLABEL(fselect);
             strptr = settext->string;
@@ -2005,9 +2004,9 @@ void parameterize(int mode, char *key)
    else
       ptype = ALL_TYPES;
 
-   for (fselect = areastruct.selectlist; fselect < areastruct.selectlist +
-            areastruct.selects; fselect++) {
-      if ((mode == P_SUBSTRING) && (areastruct.selects == 1) &&
+   for (fselect = areawin->selectlist; fselect < areawin->selectlist +
+            areawin->selects; fselect++) {
+      if ((mode == P_SUBSTRING) && (areawin->selects == 1) &&
 		(SELECTTYPE(fselect) == LABEL)) {
          settext = SELTOLABEL(fselect);
          makeparam(settext, key);
@@ -2033,7 +2032,7 @@ Boolean paramcross(objectptr tobj, labelptr tlab)
    stringpart *firstptr, *lastptr;
    int locpos;
 
-   lastptr = findstringpart(textpos, &locpos, tlab->string, areastruct.topinstance);
+   lastptr = findstringpart(textpos, &locpos, tlab->string, areawin->topinstance);
 
    /* This text position can't be inside another parameter */
    for (firstptr = lastptr; firstptr != NULL; firstptr = firstptr->nextpart)
@@ -2042,7 +2041,7 @@ Boolean paramcross(objectptr tobj, labelptr tlab)
    /* The area between textend and textpos cannot contain a parameter */
    if (textend > 0)
       for (firstptr = findstringpart(textend, &locpos, tlab->string,
-		areastruct.topinstance); firstptr != lastptr;
+		areawin->topinstance); firstptr != lastptr;
 		firstptr = firstptr->nextpart)
          if (firstptr->type == PARAM_START || firstptr->type == PARAM_END)
 	    return True;
@@ -2059,7 +2058,7 @@ int checklibtop()
    int i;
    pushlistptr thispush;
 
-   for (thispush = areastruct.stack; thispush != NULL; thispush = thispush->next)
+   for (thispush = areawin->stack; thispush != NULL; thispush = thispush->next)
       if ((i = is_library(thispush->thisinst->thisobject)) >= 0)
 	 return i;
 
