@@ -35,6 +35,7 @@ extern int XcTagCallback(Tcl_Interp *, int, Tcl_Obj *CONST objv[]);
 extern Tcl_Obj *evaluate_raw(oparamptr, int *);
 extern char *TCL_to_PS(char *);
 extern XCWindowData *GUI_init(int, Tcl_Obj *CONST objv[]);
+extern void build_app_database(Tk_Window);
 #endif
 
 extern char *evaluate_expr(oparamptr, objinstptr);
@@ -468,85 +469,32 @@ extern void startcatalog(xcWidget, pointertype, caddr_t);
 
 /* from menucalls.c: */
 
-extern void dotoolbar(xcWidget, caddr_t, caddr_t);
-extern void overdrawpixmap(xcWidget);
-extern void getgeneric(buttonsave *, xcWidget, void (*getfunction)(), void *);
 extern void setgrid(xcWidget, float *);
 extern void measurestr(float, char *);
-extern void getsnapspace(xcWidget, caddr_t, caddr_t);
-extern void getgridspace(xcWidget, caddr_t, caddr_t);
-extern void setfloat(xcWidget, float *);
 extern void setwidth(xcWidget, float *);
-extern void settsize(xcWidget, labelptr);
-extern void autoset(xcWidget, xcWidgetList, caddr_t);
-extern void autostop(xcWidget, caddr_t, caddr_t);
+extern void changetextscale(float);
 extern void autoscale(int);
-extern void setscaley(xcWidget, float *);
-extern void setscalex(xcWidget, float *);
-extern void setorient(xcWidget, short *);
-extern void setpmode(xcWidget, short *);
-extern void setpagesize(xcWidget, XPoint *);
-extern void getkern(xcWidget, caddr_t, caddr_t);
-extern void setkern(xcWidget, stringpart *);
-extern void getdscale(xcWidget, caddr_t, caddr_t);
-extern void setdscale(xcWidget, XPoint *);
-extern labelptr gettextsize(float **);
-/* Xt */ extern void gettsize(xcWidget, caddr_t, caddr_t);
-extern void setosize(xcWidget, objinstptr);
-extern void getosize(xcWidget, caddr_t, caddr_t);
-extern void getwirewidth(xcWidget, caddr_t, caddr_t);
-extern void setwwidth(xcWidget, void *);
-extern void getwwidth(xcWidget, caddr_t, caddr_t);
-extern void getfloat(xcWidget, float *, caddr_t);
-extern void setfilename(xcWidget, char **);
-extern void setpagelabel(xcWidget, char *);
-extern void makenewfontbutton();
-extern void makenewencodingbutton(char *, char);
-extern void togglefontmark(int);
-#ifndef TCL_WRAPPER
-extern void toggleexcl(xcWidget, menuptr, int);
-extern void highlightexcl(xcWidget, int, int);
-extern void toolcursor(int);
-extern void promptparam(xcWidget, caddr_t, caddr_t);
-#endif
-extern void stringparam(xcWidget, caddr_t, caddr_t);
-extern void toggle(xcWidget, pointertype, Boolean *);
-extern int setelementstyle(xcWidget, u_short, u_short);
-extern void setcolorscheme(Boolean);
-extern void inversecolor(xcWidget, pointertype, caddr_t);
-extern void togglegrid(u_short);
 extern float parseunits(char *);
-extern void setgridtype(char *);
+extern Boolean setoutputpagesize(XPoint *);
+extern void setkern(xcWidget, stringpart *);
+extern void setdscale(xcWidget, XPoint *);
+extern void setosize(xcWidget, objinstptr);
+extern void setwwidth(xcWidget, void *);
+extern labelptr gettextsize(float **);
+extern void stringparam(xcWidget, caddr_t, caddr_t);
+extern int setelementstyle(xcWidget, u_short, u_short);
+extern void togglegrid(u_short);
+extern void togglefontmark(int);
+extern void setcolorscheme(Boolean);
 extern void getgridtype(xcWidget, pointertype, caddr_t);
 extern void newlibrary(xcWidget, caddr_t, caddr_t);
-extern int findemptylib();
 extern int createlibrary(Boolean);
-extern void newpagemenu(xcWidget, pointertype, caddr_t);
 extern void makepagebutton();
-extern void renamepage(short);
-extern void renamelib(short);
-extern void setcolormark(int);
-extern void setallstylemarks(u_short);
+extern int findemptylib();
 extern polyptr checkforbbox(objectptr);
-#ifndef TCL_WRAPPER
-extern void setfill(xcWidget, pointertype, caddr_t);
-extern void makebbox(xcWidget, pointertype, caddr_t);
-extern void setclosure(xcWidget, pointertype, caddr_t);
-extern void setopaque(xcWidget, pointertype, caddr_t);
-extern void changetool(xcWidget, pointertype, caddr_t);
-extern void exec_or_changetool(xcWidget, pointertype, caddr_t);
-extern void rotatetool(xcWidget, pointertype, caddr_t);
-extern void pantool(xcWidget, pointertype, caddr_t);
-#endif
-extern int setline(xcWidget, pointertype, caddr_t);
 #ifdef TCL_WRAPPER
 extern void setcolor(xcWidget, int);
-#else
-extern void setcolor(xcWidget, pointertype, caddr_t);
 #endif
-extern void setnewcolor(xcWidget, caddr_t);
-extern void addnewcolor(xcWidget, caddr_t, caddr_t);
-extern void setfontmarks(short, short);
 extern void startparam(xcWidget, pointertype, caddr_t);
 extern void startunparam(xcWidget, pointertype, caddr_t);
 extern void setdefaultfontmarks();
@@ -557,7 +505,6 @@ extern void setvjust(xcWidget, pointertype, caddr_t);
 extern void sethjust(xcWidget, pointertype, caddr_t);
 extern void boxedit(xcWidget, pointertype, caddr_t);
 extern void locloadfont(xcWidget, char *);
-extern void addnewfont(xcWidget, caddr_t, caddr_t);
 extern short findbestfont(short, short, short, short);
 extern void setfontval(xcWidget, pointertype, labelptr);
 extern void setfont(xcWidget, pointertype, caddr_t);
@@ -566,12 +513,72 @@ extern void fontstyle(xcWidget, pointertype, caddr_t);
 extern void setfontencoding(xcWidget, pointertype, labelptr);
 extern void fontencoding(xcWidget, pointertype, caddr_t);
 extern void addtotext(xcWidget, pointertype, caddr_t);
+extern Boolean dospecial(void);
+
+/* from xtfuncs.c: */
+
+#ifndef TCL_WRAPPER
+extern void setfloat(xcWidget, float *);
+extern void autoset(xcWidget, xcWidgetList, caddr_t);
+extern void autostop(xcWidget, caddr_t, caddr_t);
+extern void togglegridstyles(xcWidget);
+extern void togglejustifs(xcWidget);
+extern void togglefontstyles(xcWidget);
+extern void toggleencodings(xcWidget);
+extern void getkern(xcWidget, caddr_t, caddr_t);
+extern void setcolor(xcWidget, pointertype, caddr_t);
+extern void setfill(xcWidget, pointertype, caddr_t);
+extern void makebbox(xcWidget, pointertype, caddr_t);
+extern void setclosure(xcWidget, pointertype, caddr_t);
+extern void setopaque(xcWidget, pointertype, caddr_t);
+extern void setline(xcWidget, pointertype, caddr_t);
+extern void changetool(xcWidget, pointertype, caddr_t);
+extern void exec_or_changetool(xcWidget, pointertype, caddr_t);
+extern void rotatetool(xcWidget, pointertype, caddr_t);
+extern void pantool(xcWidget, pointertype, caddr_t);
+extern void toggleexcl(xcWidget, menuptr, int);
+extern void highlightexcl(xcWidget, int, int);
+extern void toolcursor(int);
+extern void promptparam(xcWidget, caddr_t, caddr_t);
+extern void gettsize(xcWidget, caddr_t, caddr_t);
+extern void settsize(xcWidget, labelptr);
+extern void dotoolbar(xcWidget, caddr_t, caddr_t);
+extern void overdrawpixmap(xcWidget);
+extern buttonsave *getgeneric(xcWidget, void (*getfunction)(), void *);
+extern void getsnapspace(xcWidget, caddr_t, caddr_t);
+extern void getgridspace(xcWidget, caddr_t, caddr_t);
+extern void setscaley(xcWidget, float *);
+extern void setscalex(xcWidget, float *);
+extern void setorient(xcWidget, short *);
+extern void setpmode(xcWidget, short *);
+extern void setpagesize(xcWidget, XPoint *);
+extern void getdscale(xcWidget, caddr_t, caddr_t);
+extern void getosize(xcWidget, caddr_t, caddr_t);
+extern void getwirewidth(xcWidget, caddr_t, caddr_t);
+extern void getwwidth(xcWidget, caddr_t, caddr_t);
+extern void getfloat(xcWidget, float *, caddr_t);
+extern void setfilename(xcWidget, char **);
+extern void setpagelabel(xcWidget, char *);
+extern void makenewfontbutton();
+extern void newpagemenu(xcWidget, pointertype, caddr_t);
+extern void makenewencodingbutton(char *, char);
+extern void toggle(xcWidget, pointertype, Boolean *);
+extern void inversecolor(xcWidget, pointertype, caddr_t);
+extern void setgridtype(char *);
+extern void renamepage(short);
+extern void renamelib(short);
+extern void setcolormark(int);
+extern void setallstylemarks(u_short);
+extern void setnewcolor(xcWidget, caddr_t);
+extern void addnewcolor(xcWidget, caddr_t, caddr_t);
+extern void setfontmarks(short, short);
 extern void position_popup(xcWidget, xcWidget);
 extern void border_popup(xcWidget, caddr_t, caddr_t);
 extern void color_popup(xcWidget, caddr_t, caddr_t);
 extern void fill_popup(xcWidget, caddr_t, caddr_t);
 extern void param_popup(xcWidget, caddr_t, caddr_t);
-extern Boolean dospecial(void);
+extern void addnewfont(xcWidget, caddr_t, caddr_t);
+#endif
 
 /* from netlist.c: */
 
@@ -873,6 +880,7 @@ extern void addtocolorlist(xcWidget, int);
 extern int addnewcolorentry(int);
 extern int xc_getlayoutcolor(int);
 extern int query_named_color(char *);
+extern caddr_t CvtStringToPixel(XrmValuePtr, int *, XrmValuePtr, XrmValuePtr);
 extern void outputpopup(xcWidget, caddr_t, caddr_t);
 extern void docommand();
 extern void destroypopup(xcWidget, popupstruct *, caddr_t);
@@ -893,4 +901,5 @@ extern void updatetext(xcWidget, xcWidgetList, caddr_t);
 extern void delwin(xcWidget, popupstruct *, XClientMessageEvent *);
 #endif
 
+
 extern void makecursors();
