@@ -80,45 +80,6 @@ void callwritenet(xcWidget w, pointertype mode, caddr_t calldata)
    }
 }
 
-/*--------------------------------------------------------------*/
-/* Enable schematic capture (set schemon and realize widgets)	*/
-/* If mode == 1, do a redraw (e.g., not called during a file	*/
-/* load)							*/
-/*--------------------------------------------------------------*/
-
-void doxschema(xcWidget w, pointertype mode, caddr_t calldata)
-{
-   Arg wargs[1];
-
-   if (areawin->schemon) {
-      areawin->schemon = False;
-#ifndef TCL_WRAPPER
-      XtUnmanageChild(wschema);
-      XtUnmanageChild(wsymb);
-      XtUnmanageChild(netbutton);
-
-      XtSetArg(wargs[0], XtNlabel, "Enable XSchema");
-      XtSetValues(OptionsEnableXSchemaButton, wargs, 1);
-#endif
-   }
-   else {
-      areawin->schemon = True;
-#ifndef TCL_WRAPPER
-      XtManageChild(wschema);
-      XtManageChild(wsymb);
-      XtManageChild(netbutton);
-
-      XtSetArg(wargs[0], XtNlabel, "Disable XSchema");
-      XtSetValues(OptionsEnableXSchemaButton, wargs, 1);
-#endif
-   }
-
-   /* Redraw the screen, since this action may effect the presence of	*/
-   /* pins and schematic informational labels.				*/
-
-   if (mode) drawarea(NULL, NULL, NULL);
-}
-
 /*----------------------------------------------------------------------*/
 /* Find the page object and instance with the indicated name.		*/
 /*----------------------------------------------------------------------*/
@@ -298,7 +259,7 @@ void connectivity(xcWidget button, caddr_t clientdata, caddr_t calldata)
    if (ggen != NULL) {
       if (checkvalid(topobject) == -1) {
          destroynets(topobject);
-         createnets(areawin->topinstance);
+         createnets(areawin->topinstance, FALSE);
       }
       if ((netlist = is_resolved(&ggen, seltop, &nettop)) != NULL) {
          depth = pushnetwork(seltop, nettop);
@@ -378,6 +339,9 @@ Boolean setobjecttype(objectptr cschem)
    genericptr *cgen;
    labelptr clab;
 
+   /* If networks are specifically prohibited. . . */
+   if (cschem->schemtype == NONETWORK) return False;
+
    /* Apply only to schematic objects */
 
    if ((cschem->schemtype != PRIMARY) && (cschem->schemtype != SECONDARY)) {
@@ -692,7 +656,7 @@ int checkschem(objectptr thisobj, char *cname)
    objectptr *tlib;
    short i, j;
 
-   if ((areawin->schemon == False) || (thisobj->symschem != NULL)) return 0;
+   if (thisobj->symschem != NULL) return 0;
 
    for (i = 0; i < xobjs.numlibs; i++) {
       for (j = 0; j < xobjs.userlibs[i].number; j++) {
@@ -720,7 +684,7 @@ int checksym(objectptr symobj, char *cname)
    short cpage;
    objectptr checkpage;
 
-   if (areawin->schemon == False || symobj->symschem != NULL) return 0;
+   if (symobj->symschem != NULL) return 0;
 
    for (cpage = 0; cpage < xobjs.pages; cpage++) {
       if (xobjs.pagelist[cpage]->pageinst != NULL) {
@@ -789,7 +753,6 @@ void swapschem(int allow_create, int libnum)
    pushlistptr stacktop;
    short loclibnum = libnum;
 
-   if (areawin->schemon == False) return;
    if (libnum == -1) loclibnum = USERLIB - LIBRARY;
 
    if (eventmode == MOVE_MODE || eventmode == COPY_MODE)
@@ -836,6 +799,8 @@ void swapschem(int allow_create, int libnum)
 	 /* Generate a library instance for this object and set the */
 	 /* top instance to point to it.			    */
 
+	 topobject->viewscale = areawin->vscale;
+	 topobject->pcorner = areawin->pcorner;
 	 push_stack(&areawin->stack, areawin->topinstance);
 	 areawin->topinstance = addtoinstlist(loclibnum, *newobject, FALSE);
 
@@ -902,6 +867,8 @@ void swapschem(int allow_create, int libnum)
 
       if (areawin->stack && areawin->stack->thisinst->thisobject
 			== topobject->symschem) {
+	 topobject->viewscale = areawin->vscale;
+	 topobject->pcorner = areawin->pcorner;
 	 areawin->topinstance = areawin->stack->thisinst;
 	 pop_stack(&areawin->stack);
       }
@@ -939,6 +906,8 @@ void swapschem(int allow_create, int libnum)
 	    }
          }
 	       
+	 topobject->viewscale = areawin->vscale;
+	 topobject->pcorner = areawin->pcorner;
 	 push_stack(&areawin->stack, areawin->topinstance);
 	 areawin->topinstance = syminst;
       }
@@ -978,10 +947,6 @@ void dobeforeswap(xcWidget w, caddr_t clientdata, caddr_t calldata)
 {
    buttonsave *popdata = (buttonsave *)malloc(sizeof(buttonsave));
 
-   /* Check if this function is valid */
-
-   if (areawin->schemon == False) return;
-
    /* Check for requirement to change the name before creating the symbol */
 
    if ((topobject->symschem == NULL) && (topobject->schemtype == PRIMARY)
