@@ -748,6 +748,7 @@ void draw_all_selected()
 void draw_normal_selected(objectptr thisobj, objinstptr thisinst)
 {
    short *lastselect;
+   int i;
 
    if (areawin->selects == 0) return;
    else if (areawin->hierstack != NULL) return;
@@ -756,8 +757,8 @@ void draw_normal_selected(objectptr thisobj, objinstptr thisinst)
 
    SetFunction(dpy, areawin->gc, GXcopy);
 
-   for (lastselect = areawin->selectlist; lastselect < areawin->selectlist 
-	+ areawin->selects; lastselect++) {
+   for (i = 0; i < areawin->selects; i++) {
+      lastselect = areawin->selectlist + i;
       XTopSetForeground(SELTOCOLOR(lastselect)); 
       geneasydraw(*lastselect, SELTOCOLOR(lastselect), thisobj, thisinst);
    }
