@@ -50,12 +50,6 @@ typedef struct {
    short yaxis;
 } arcinfo;
 
-typedef struct {
-   short number;
-   genericptr *element;
-   short *idx;
-} uselection;
-
 typedef struct {
    genericptr element;		/* element being edited */
    union {
@@ -129,7 +123,7 @@ uselection *remember_selection(objinstptr topinst, short *slist, int number)
 }
 
 /*----------------------------------------------------------------------*/
-/* Create a selection list in areawin->from the saved uselection	*/
+/* Create a selection list in areawin from the saved uselection	*/
 /* record.								*/
 /*----------------------------------------------------------------------*/
 
