@@ -1094,21 +1094,18 @@ typedef struct {
    /* color scheme 1 */
    Pixel	fg, bg;
    Pixel	gridpix, snappix, selectpix, axespix;
-   Pixel	buttonpix, querypix, filterpix;
-   Pixel	auxpix, barpix, parampix;
+   Pixel	buttonpix, filterpix, auxpix, barpix, parampix;
 
    /* color scheme 2 */
-
    Pixel	fg2, bg2;
    Pixel	gridpix2, snappix2, selectpix2, axespix2;
-   Pixel	buttonpix2, querypix2, filterpix2;
-   Pixel	auxpix2, barpix2, parampix2;
+   Pixel	buttonpix2, auxpix2, parampix2;
 
    int		width, height, timeout;
-   XFontStruct	*helpfont, *filefont;
+   XFontStruct	*filefont;
 
 #ifndef TCL_WRAPPER
-   XFontStruct	*xcfont, *textfont, *titlefont;
+   XFontStruct	*xcfont, *textfont, *titlefont, *helpfont;
 #endif
 
 } ApplicationData, *ApplicationDataPtr;
